from .endpoint import EndpointType
from .endpoint_extension import ENDPOINT_EXTENSION_TYPE, EndpointExtension

__all__ = [
    "EndpointType",
    "EndpointExtension",
    "ENDPOINT_EXTENSION_TYPE",
]



from __future__ import annotations

from dataclasses import dataclass
from typing import Literal, TypedDict

from omu.identifier import Identifier
from omu.localization import LocalizedText
from omu.model import Model

type PermissionLevel = Literal["low", "medium", "high"]


class PermissionMetadata(TypedDict):
    name: LocalizedText
    note: LocalizedText
    level: PermissionLevel


class PermissionTypeJson(TypedDict):
    id: str
    metadata: PermissionMetadata


@dataclass(frozen=True, slots=True)
class PermissionType(Model[PermissionTypeJson]):
    id: Identifier
    metadata: PermissionMetadata

    @classmethod
    def create(
        cls,
        identifier: Identifier,
        name: str,
        metadata: PermissionMetadata,
    ) -> PermissionType:
        return PermissionType(
            id=identifier / name,
            metadata=metadata,
        )

    def to_json(self) -> PermissionTypeJson:
        return {
            "id": self.id.key(),
            "metadata": self.metadata,
        }

    @classmethod
    def from_json(cls, json: PermissionTypeJson) -> PermissionType:
        return PermissionType(
            id=Identifier.from_key(json["id"]),
            metadata=json["metadata"],
        )



from .extension import Extension, ExtensionType
from .extension_registry import ExtensionRegistry

__all__ = [
    "Extension",
    "ExtensionType",
    "ExtensionRegistry",
    "ExtensionRegistry",
]



from .package_info import PackageInfo
from .plugin import PluginPackageInfo
from .plugin_extension import PLUGIN_EXTENSION_TYPE, PluginExtension

__all__ = [
    "PackageInfo",
    "PluginPackageInfo",
    "PLUGIN_EXTENSION_TYPE",
    "PluginExtension",
]



from .i18n_extension import (
    I18N_EXTENSION_TYPE,
    I18N_GET_LOCALES_PERMISSION_ID,
    I18N_SET_LOCALES_PERMISSION_ID,
    I18nExtension,
)

__all__ = [
    "I18N_EXTENSION_TYPE",
    "I18N_GET_LOCALES_PERMISSION_ID",
    "I18N_SET_LOCALES_PERMISSION_ID",
    "I18nExtension",
]
